@@ -64,7 +64,7 @@ async def dshell_respond_interaction(ctx: Interaction,
 
     return sended_message.id
 
-async def dshell_defer_interaction(ctx: Interaction, hide: bool = False) -> bool:
+async def dshell_defer_interaction(ctx: Interaction) -> bool:
     """
     Defer a message interaction on Discord
     """
@@ -72,10 +72,7 @@ async def dshell_defer_interaction(ctx: Interaction, hide: bool = False) -> bool
     if not isinstance(ctx, Interaction):
         raise Exception(f'Respond to an interaction must be used in an interaction context, not {type(ctx)} !')
 
-    if not isinstance(hide, bool):
-        raise Exception(f'Hide parameter must be a boolean, not {type(hide)} !')
-
-    await ctx.response.defer(ephemeral=hide)
+    await ctx.response.defer()
 
     return True
 
