@@ -139,10 +139,18 @@ class DshellInterpreteur:
                     self.env[node.name.value] = eval_expression_inline(first_node, self)
 
                 elif isinstance(first_node, EmbedNode):
-                    self.env[node.name.value] = build_embed(first_node.body, first_node.fields, self)
+                    # rebuild the embed if it already exists
+                    if node.name.value in self.env and isinstance(self.env[node.name.value], Embed):
+                        self.env[node.name.value] = rebuild_embed(self.env[node.name.value], first_node.body, first_node.fields, self)
+                    else:
+                        self.env[node.name.value] = build_embed(first_node.body, first_node.fields, self)
 
                 elif isinstance(first_node, PermissionNode):
-                    self.env[node.name.value] = build_permission(first_node.body, self)
+                    # rebuild the permissions if it already exists
+                    if node.name.value in self.env and isinstance(self.env[node.name.value], dict):
+                        self.env[node.name.value].update(build_permission(first_node.body, self))
+                    else:
+                        self.env[node.name.value] = build_permission(first_node.body, self)
 
                 elif isinstance(first_node, UiNode):
                     # rebuild the UI if it already exists
@@ -410,9 +418,9 @@ def length(variable : LengthNode) -> int:
     else:
         return len(variable.body.value)
 
-def build_embed(body: list[Token], fields: list[FieldEmbedNode], interpreter: DshellInterpreteur) -> Embed:
+def build_embed_args(body: list[Token], fields: list[FieldEmbedNode], interpreter: DshellInterpreteur) -> tuple[dict, list[dict]]:
     """
-    Builds an embed from the command information.
+    Builds the arguments for an embed from the command information.
     """
     args_main_embed: dict[str, list[Any]] = regroupe_commandes(body, interpreter)[0]
     args_main_embed.pop('*')  # remove unspecified parameters for the embed
@@ -430,12 +438,39 @@ def build_embed(body: list[Token], fields: list[FieldEmbedNode], interpreter: Ds
     if 'color' in args_main_embed:
         args_main_embed['color'] = build_colour(args_main_embed['color'])  # convert color to Colour object or int
 
+    return args_main_embed, args_fields
+
+def build_embed(body: list[Token], fields: list[FieldEmbedNode], interpreter: DshellInterpreteur) -> Embed:
+    """
+    Builds an embed from the command information.
+    """
+
+    args_main_embed, args_fields = build_embed_args(body, fields, interpreter)
     embed = Embed(**args_main_embed)  # build the main embed
     for field in args_fields:
         embed.add_field(**field)  # add all fields
 
     return embed
 
+def rebuild_embed(embed: Embed, body: list[Token], fields: list[FieldEmbedNode], interpreter: DshellInterpreteur) -> Embed:
+    """
+    Rebuilds an embed from an existing embed and the command information.
+    """
+    args_main_embed, args_fields = build_embed_args(body, fields, interpreter)
+
+    for key, value in args_main_embed.items():
+        if key == 'color':
+            embed.colour = value
+        else:
+            setattr(embed, key, value)
+
+    if args_fields:
+        embed.clear_fields()
+        for field in args_fields:
+            embed.add_field(**field)
+
+    return embed
+
 def build_colour(color: Union[int, ListNode]) -> Union[Colour, int]:
     """
     Builds a Colour object from an integer or a ListNode.
